""" yahoo.search.version - Version information
"""

version = "3.1"
authorName = "Leif Hedstrom"
authorMail = "leif@ogre.com"
maintainerName = "Leif Hedstrom"
maintainerMail = "leif@ogre.com"
credits = """- The entire Yahoo search team, of course.
"""

author = "%s <%s>" % (authorName, authorMail)


__revision__ = "$Id: version.py,v 1.13 2007/09/11 21:49:48 zwoop Exp $"
__version__ = "$Revision: 1.13 $"
__author__ = "Leif Hedstrom <leif@ogre.com>"
__date__ = "Tue Sep 11 15:49:27 MDT 2007"



#
# local variables:
# mode: python
# indent-tabs-mode: nil
# py-indent-offset: 4
# end:
